diff --git a/frontend-modern/src/components/FirstRunSetup.tsx b/frontend-modern/src/components/FirstRunSetup.tsx
index 665b374..7ad0e67 100644
--- a/frontend-modern/src/components/FirstRunSetup.tsx
+++ b/frontend-modern/src/components/FirstRunSetup.tsx
@@ -319,18 +319,22 @@ IMPORTANT: Keep these credentials secure!
>
# From container host:
docker exec <container-name> cat {bootstrapTokenPath()}
- # Or kubectl for Kubernetes:
+ # For Kubernetes:
kubectl exec <pod-name> -- cat {bootstrapTokenPath()}
- # Or exec into the container:
+ # For Proxmox LXC running Docker:
+ pct exec <ctid> -- docker exec <container-name> cat {bootstrapTokenPath()}
+ # Or enter the LXC container first:
+ pct enter <ctid>
+ # Then inside LXC:
# For Proxmox LXC, run from Proxmox host:
pct enter <ctid>
# Or directly retrieve:
pct exec <ctid> -- cat {bootstrapTokenPath()}
- # Or from inside the container:
+ # Or from inside the LXC container:
cat {bootstrapTokenPath()}
@@ -319,18 +319,22 @@ IMPORTANT: Keep these credentials secure!
>
- # From container host:
+ # From Docker host:
docker exec <container-name> cat {bootstrapTokenPath()}